// utils/date.js
export function formatDate(date, format = 'YYYY-MM-DD') {
  if (!date) return '';
  
  const d = date instanceof Date ? date : new Date(date);
  if (isNaN(d.getTime())) return ''; // 处理无效日期
  
  const pad = num => String(num).padStart(2, '0');
  
  const replacements = {
    YYYY: d.getFullYear(),
    MM: pad(d.getMonth() + 1),
    DD: pad(d.getDate()),
    HH: pad(d.getHours()),
    mm: pad(d.getMinutes()),
    ss: pad(d.getSeconds()),
    YY: String(d.getFullYear()).slice(-2),
    M: d.getMonth() + 1, // 不补零
    D: d.getDate(),
    H: d.getHours(),
    m: d.getMinutes(),
    s: d.getSeconds()
  };

  return format.replace(
    /YYYY|YY|MM|M|DD|D|HH|H|mm|m|ss|s/g,
    match => replacements[match]
  );
}

// 新增：获取月份范围（用于图表X轴）
export function getMonthDays(date) {
  const d = new Date(date);
  const year = d.getFullYear();
  const month = d.getMonth() + 1;
  const days = new Date(year, month, 0).getDate();
  
  return Array.from({ length: days }, (_, i) => `${i + 1}日`);
}